@@ -54,6 +54,34 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def AttachLoadBalancers(self, request):
+        """此接口（AttachLoadBalancers）用于将负载均衡器添加到伸缩组。
+
+        :param request: Request instance for AttachLoadBalancers.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.AttachLoadBalancersRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.AttachLoadBalancersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AttachLoadBalancers", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AttachLoadBalancersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ClearLaunchConfigurationAttributes(self, request):
         """本接口（ClearLaunchConfigurationAttributes）用于将启动配置内的特定属性完全清空。
 
@@ -303,34 +331,6 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def CreatePaiInstance(self, request):
-        """本接口 (CreatePaiInstance) 用于创建一个指定配置的PAI实例。
-
-        :param request: Request instance for CreatePaiInstance.
-        :type request: :class:`tencentcloud.autoscaling.v20180419.models.CreatePaiInstanceRequest`
-        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.CreatePaiInstanceResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CreatePaiInstance", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreatePaiInstanceResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CreateScalingPolicy(self, request):
         """本接口（CreateScalingPolicy）用于创建告警触发策略。
 
@@ -613,6 +613,34 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeAutoScalingAdvices(self, request):
+        """此接口用于查询伸缩组配置建议。
+
+        :param request: Request instance for DescribeAutoScalingAdvices.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.DescribeAutoScalingAdvicesRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.DescribeAutoScalingAdvicesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeAutoScalingAdvices", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeAutoScalingAdvicesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAutoScalingGroupLastActivities(self, request):
         """本接口（DescribeAutoScalingGroupLastActivities）用于查询伸缩组的最新一次伸缩活动记录。
 
@@ -917,6 +945,34 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DetachLoadBalancers(self, request):
+        """本接口（DetachLoadBalancers）用于从伸缩组移出负载均衡器，本接口不会销毁负载均衡器。
+
+        :param request: Request instance for DetachLoadBalancers.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.DetachLoadBalancersRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.DetachLoadBalancersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DetachLoadBalancers", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DetachLoadBalancersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DisableAutoScalingGroup(self, request):
         """本接口（DisableAutoScalingGroup）用于停用指定伸缩组。
 
@@ -1091,6 +1147,34 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyLoadBalancerTargetAttributes(self, request):
+        """本接口（ModifyLoadBalancerTargetAttributes）用于修改伸缩组内负载均衡器的目标规则属性。
+
+        :param request: Request instance for ModifyLoadBalancerTargetAttributes.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.ModifyLoadBalancerTargetAttributesRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.ModifyLoadBalancerTargetAttributesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyLoadBalancerTargetAttributes", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyLoadBalancerTargetAttributesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyLoadBalancers(self, request):
         """本接口（ModifyLoadBalancers）用于修改伸缩组的负载均衡器。
 
@@ -1208,34 +1292,6 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def PreviewPaiDomainName(self, request):
-        """本接口（PreviewPaiDomainName）用于预览PAI实例域名。
-
-        :param request: Request instance for PreviewPaiDomainName.
-        :type request: :class:`tencentcloud.autoscaling.v20180419.models.PreviewPaiDomainNameRequest`
-        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.PreviewPaiDomainNameResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("PreviewPaiDomainName", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.PreviewPaiDomainNameResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def RemoveInstances(self, request):
         """本接口（RemoveInstances）用于从伸缩组删除 CVM 实例。根据当前的产品逻辑，如果实例由弹性伸缩自动创建，则实例会被销毁；如果实例系创建后加入伸缩组的，则会从伸缩组中移除，保留实例。
         * 如果删除指定实例后，伸缩组内处于`IN_SERVICE`状态的实例数量小于伸缩组最小值，接口将报错
