@@ -1483,7 +1483,14 @@ class ClsClient(AbstractClient):
 
 
     def UploadLog(self, request, body):
-        """## 功能描述
+        """## 提示
+        为了保障您日志数据的可靠性以及更高效地使用日志服务，建议您使用CLS优化后的接口[上传结构化日志](https://cloud.tencent.com/document/api/614/16873)上传日志。
+
+        同时我们给此接口专门优化定制了多个语言版本的SDK供您选择，SDK提供统一的异步发送、资源控制、自动重试、优雅关闭、感知上报等功能，使上报日志功能更完善，详情请参考[SDK采集](https://cloud.tencent.com/document/product/614/67157)。
+
+        同时云API上传日志接口也支持同步上传日志数据，如果您选继续使用此接口请参考下文。
+
+        ## 功能描述
 
         本接口用于将日志写入到指定的日志主题。
 
