@@ -24,9 +24,13 @@ class AutoSummarizationRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 待处理的文本（仅支持UTF-8格式，不超过2000字）
+        :type Text: str
+        :param Length: 指定摘要的长度上限（默认值为200）
+注：为保证摘要的可读性，最终生成的摘要长度会低于指定的长度上限。
+        :type Length: int
         """
-        :param Text: 待处理的文本（仅支持UTF-8格式，不超过2000字）\n        :type Text: str\n        :param Length: 指定摘要的长度上限（默认值为200）
-注：为保证摘要的可读性，最终生成的摘要长度会低于指定的长度上限。\n        :type Length: int\n        """
         self.Text = None
         self.Length = None
 
@@ -49,8 +53,12 @@ class AutoSummarizationResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Summary: 文本摘要结果
+        :type Summary: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Summary: 文本摘要结果\n        :type Summary: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Summary = None
         self.RequestId = None
 
@@ -66,8 +74,14 @@ class CCIToken(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Word: 错别字内容
+        :type Word: str
+        :param BeginOffset: 错别字的起始位置，从0开始
+        :type BeginOffset: int
+        :param CorrectWord: 错别字纠错结果
+        :type CorrectWord: str
         """
-        :param Word: 错别字内容\n        :type Word: str\n        :param BeginOffset: 错别字的起始位置，从0开始\n        :type BeginOffset: int\n        :param CorrectWord: 错别字纠错结果\n        :type CorrectWord: str\n        """
         self.Word = None
         self.BeginOffset = None
         self.CorrectWord = None
@@ -92,8 +106,14 @@ class ChatBotRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Query: 用户请求的query
+        :type Query: str
+        :param OpenId: 服务的id,  主要用于儿童闲聊接口，比如手Q的openid
+        :type OpenId: str
+        :param Flag: 0: 通用闲聊, 1:儿童闲聊, 默认是通用闲聊
+        :type Flag: int
         """
-        :param Query: 用户请求的query\n        :type Query: str\n        :param OpenId: 服务的id,  主要用于儿童闲聊接口，比如手Q的openid\n        :type OpenId: str\n        :param Flag: 0: 通用闲聊, 1:儿童闲聊, 默认是通用闲聊\n        :type Flag: int\n        """
         self.Query = None
         self.OpenId = None
         self.Flag = None
@@ -118,8 +138,14 @@ class ChatBotResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Reply: 闲聊回复
+        :type Reply: str
+        :param Confidence: 对于当前输出回复的自信度
+        :type Confidence: float
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Reply: 闲聊回复\n        :type Reply: str\n        :param Confidence: 对于当前输出回复的自信度\n        :type Confidence: float\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Reply = None
         self.Confidence = None
         self.RequestId = None
@@ -137,16 +163,36 @@ class ClassificationResult(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param FirstClassName: 一级分类名称
+        :type FirstClassName: str
+        :param SecondClassName: 二级分类名称
+        :type SecondClassName: str
+        :param FirstClassProbability: 一级分类概率
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FirstClassProbability: float
+        :param SecondClassProbability: 二级分类概率
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SecondClassProbability: float
+        :param ThirdClassName: 三级分类名称，仅有当新闻领域五分类可能出现，详情见文本分类文档
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ThirdClassName: str
+        :param ThirdClassProbability: 三级分类概率，仅有当新闻领域五分类可能出现，详情见文本分类文档
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ThirdClassProbability: float
+        :param FourthClassName: 四级分类名称，仅有当新闻领域五分类可能出现，详情见文本分类文档
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FourthClassName: str
+        :param FourthClassProbability: 四级分类概率，仅有当新闻领域五分类可能出现，详情见文本分类文档
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FourthClassProbability: float
+        :param FifthClassName: 五级分类名称，仅有当新闻领域五分类可能出现，详情见文本分类文档
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FifthClassName: str
+        :param FifthClassProbability: 五级分类概率，仅有当新闻领域五分类可能出现，详情见文本分类文档
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FifthClassProbability: float
         """
-        :param FirstClassName: 一级分类名称\n        :type FirstClassName: str\n        :param SecondClassName: 二级分类名称\n        :type SecondClassName: str\n        :param FirstClassProbability: 一级分类概率
-注意：此字段可能返回 null，表示取不到有效值。\n        :type FirstClassProbability: float\n        :param SecondClassProbability: 二级分类概率
-注意：此字段可能返回 null，表示取不到有效值。\n        :type SecondClassProbability: float\n        :param ThirdClassName: 三级分类名称，仅有当新闻领域五分类可能出现，详情见文本分类文档
-注意：此字段可能返回 null，表示取不到有效值。\n        :type ThirdClassName: str\n        :param ThirdClassProbability: 三级分类概率，仅有当新闻领域五分类可能出现，详情见文本分类文档
-注意：此字段可能返回 null，表示取不到有效值。\n        :type ThirdClassProbability: float\n        :param FourthClassName: 四级分类名称，仅有当新闻领域五分类可能出现，详情见文本分类文档
-注意：此字段可能返回 null，表示取不到有效值。\n        :type FourthClassName: str\n        :param FourthClassProbability: 四级分类概率，仅有当新闻领域五分类可能出现，详情见文本分类文档
-注意：此字段可能返回 null，表示取不到有效值。\n        :type FourthClassProbability: float\n        :param FifthClassName: 五级分类名称，仅有当新闻领域五分类可能出现，详情见文本分类文档
-注意：此字段可能返回 null，表示取不到有效值。\n        :type FifthClassName: str\n        :param FifthClassProbability: 五级分类概率，仅有当新闻领域五分类可能出现，详情见文本分类文档
-注意：此字段可能返回 null，表示取不到有效值。\n        :type FifthClassProbability: float\n        """
         self.FirstClassName = None
         self.SecondClassName = None
         self.FirstClassProbability = None
@@ -185,8 +231,12 @@ class CreateDictRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Name: 自定义词库名称，不超过20字。
+        :type Name: str
+        :param Description: 自定义词库描述，不超过100字。
+        :type Description: str
         """
-        :param Name: 自定义词库名称，不超过20字。\n        :type Name: str\n        :param Description: 自定义词库描述，不超过100字。\n        :type Description: str\n        """
         self.Name = None
         self.Description = None
 
@@ -209,9 +259,13 @@ class CreateDictResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DictId: 创建的自定义词库ID。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type DictId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DictId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.DictId = None
         self.RequestId = None
 
@@ -227,8 +281,12 @@ class CreateWordItemsRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param DictId: 自定义词库ID。
+        :type DictId: str
+        :param WordItems: 待添加的词条集合。
+        :type WordItems: list of WordItem
         """
-        :param DictId: 自定义词库ID。\n        :type DictId: str\n        :param WordItems: 待添加的词条集合。\n        :type WordItems: list of WordItem\n        """
         self.DictId = None
         self.WordItems = None
 
@@ -256,8 +314,10 @@ class CreateWordItemsResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -271,8 +331,10 @@ class DeleteDictRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param DictId: 要删除的自定义词库ID。
+        :type DictId: str
         """
-        :param DictId: 要删除的自定义词库ID。\n        :type DictId: str\n        """
         self.DictId = None
 
 
@@ -293,8 +355,10 @@ class DeleteDictResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -308,8 +372,12 @@ class DeleteWordItemsRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param DictId: 自定义词库ID。
+        :type DictId: str
+        :param WordItems: 待删除的词条集合。
+        :type WordItems: list of WordItem
         """
-        :param DictId: 自定义词库ID。\n        :type DictId: str\n        :param WordItems: 待删除的词条集合。\n        :type WordItems: list of WordItem\n        """
         self.DictId = None
         self.WordItems = None
 
@@ -337,8 +405,10 @@ class DeleteWordItemsResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -352,8 +422,10 @@ class DependencyParsingRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 待分析的文本（仅支持UTF-8格式，不超过200字）
+        :type Text: str
         """
-        :param Text: 待分析的文本（仅支持UTF-8格式，不超过200字）\n        :type Text: str\n        """
         self.Text = None
 
 
@@ -374,7 +446,7 @@ class DependencyParsingResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param DpTokens: 句法依存分析结果，其中句法依存关系的类型包括：
 <li>主谓关系，eg: 我送她一束花 (我 <-- 送)
 <li>动宾关系，eg: 我送她一束花 (送 --> 花)
@@ -390,7 +462,11 @@ class DependencyParsingResponse(AbstractModel):
 <li>右附加关系，eg: 孩子们 (孩子 --> 们)
 <li>独立结构，eg: 两个单句在结构上彼此独立
 <li>标点符号，eg: 。
-<li>核心关系，eg: 整个句子的核心\n        :type DpTokens: list of DpToken\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+<li>核心关系，eg: 整个句子的核心
+        :type DpTokens: list of DpToken
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.DpTokens = None
         self.RequestId = None
 
@@ -411,8 +487,12 @@ class DescribeDictRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param DictId: 自定义词库ID。
+        :type DictId: str
+        :param Name: 自定义词库名称，模糊搜索。
+        :type Name: str
         """
-        :param DictId: 自定义词库ID。\n        :type DictId: str\n        :param Name: 自定义词库名称，模糊搜索。\n        :type Name: str\n        """
         self.DictId = None
         self.Name = None
 
@@ -435,9 +515,13 @@ class DescribeDictResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Dicts: 查询到的词库信息列表。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Dicts: list of DictInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Dicts: list of DictInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.Dicts = None
         self.RequestId = None
 
@@ -458,8 +542,12 @@ class DescribeDictsRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Limit: 每页数据量，范围为1~100，默认为10。
+        :type Limit: int
+        :param Offset: 分页偏移量，从0开始，默认为0。
+        :type Offset: int
         """
-        :param Limit: 每页数据量，范围为1~100，默认为10。\n        :type Limit: int\n        :param Offset: 分页偏移量，从0开始，默认为0。\n        :type Offset: int\n        """
         self.Limit = None
         self.Offset = None
 
@@ -482,9 +570,15 @@ class DescribeDictsResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TotalCount: 记录总条数。
+        :type TotalCount: int
+        :param Dicts: 自定义词库信息列表。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Dicts: list of DictInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param TotalCount: 记录总条数。\n        :type TotalCount: int\n        :param Dicts: 自定义词库信息列表。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Dicts: list of DictInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.Dicts = None
         self.RequestId = None
@@ -507,8 +601,10 @@ class DescribeEntityRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param EntityName: 实体名称
+        :type EntityName: str
         """
-        :param EntityName: 实体名称\n        :type EntityName: str\n        """
         self.EntityName = None
 
 
@@ -529,8 +625,12 @@ class DescribeEntityResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Content: 返回查询实体相关信息
+        :type Content: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Content: 返回查询实体相关信息\n        :type Content: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Content = None
         self.RequestId = None
 
@@ -546,8 +646,12 @@ class DescribeRelationRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param LeftEntityName: 输入第一个实体
+        :type LeftEntityName: str
+        :param RightEntityName: 输入第二个实体
+        :type RightEntityName: str
         """
-        :param LeftEntityName: 输入第一个实体\n        :type LeftEntityName: str\n        :param RightEntityName: 输入第二个实体\n        :type RightEntityName: str\n        """
         self.LeftEntityName = None
         self.RightEntityName = None
 
@@ -570,8 +674,12 @@ class DescribeRelationResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Content: 返回查询实体间的关系
+        :type Content: list of EntityRelationContent
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Content: 返回查询实体间的关系\n        :type Content: list of EntityRelationContent\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Content = None
         self.RequestId = None
 
@@ -592,8 +700,10 @@ class DescribeTripleRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TripleCondition: 三元组查询条件
+        :type TripleCondition: str
         """
-        :param TripleCondition: 三元组查询条件\n        :type TripleCondition: str\n        """
         self.TripleCondition = None
 
 
@@ -614,8 +724,12 @@ class DescribeTripleResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Content: 返回三元组信息
+        :type Content: list of TripleContent
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Content: 返回三元组信息\n        :type Content: list of TripleContent\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Content = None
         self.RequestId = None
 
@@ -636,8 +750,16 @@ class DescribeWordItemsRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param DictId: 自定义词库ID。
+        :type DictId: str
+        :param Offset: 分页偏移量，从0开始，默认为0。
+        :type Offset: int
+        :param Limit: 每页数据量，范围为1~100，默认为10。
+        :type Limit: int
+        :param Text: 待检索的词条文本，支持模糊匹配。
+        :type Text: str
         """
-        :param DictId: 自定义词库ID。\n        :type DictId: str\n        :param Offset: 分页偏移量，从0开始，默认为0。\n        :type Offset: int\n        :param Limit: 每页数据量，范围为1~100，默认为10。\n        :type Limit: int\n        :param Text: 待检索的词条文本，支持模糊匹配。\n        :type Text: str\n        """
         self.DictId = None
         self.Offset = None
         self.Limit = None
@@ -664,9 +786,15 @@ class DescribeWordItemsResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TotalCount: 词条记录总条数。
+        :type TotalCount: int
+        :param WordItems: 词条信息列表。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type WordItems: list of WordItem
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param TotalCount: 词条记录总条数。\n        :type TotalCount: int\n        :param WordItems: 词条信息列表。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type WordItems: list of WordItem\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.WordItems = None
         self.RequestId = None
@@ -689,11 +817,21 @@ class DictInfo(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Name: 自定义词库名称。
+        :type Name: str
+        :param Id: 自定义词库ID。
+        :type Id: str
+        :param Description: 自定义词库描述信息。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Description: str
+        :param UpdateTime: 自定义词库修改时间，形式为:yyyy-mm-dd hh:mm:ss。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type UpdateTime: str
+        :param CreateTime: 自定义词库创建时间，形式为:yyyy-mm-dd hh:mm:ss。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CreateTime: str
         """
-        :param Name: 自定义词库名称。\n        :type Name: str\n        :param Id: 自定义词库ID。\n        :type Id: str\n        :param Description: 自定义词库描述信息。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Description: str\n        :param UpdateTime: 自定义词库修改时间，形式为:yyyy-mm-dd hh:mm:ss。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type UpdateTime: str\n        :param CreateTime: 自定义词库创建时间，形式为:yyyy-mm-dd hh:mm:ss。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type CreateTime: str\n        """
         self.Name = None
         self.Id = None
         self.Description = None
@@ -722,12 +860,20 @@ class DpToken(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Relation: 句法依存关系的类型
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Relation: str\n        :param HeadId: 当前词父节点的序号
-注意：此字段可能返回 null，表示取不到有效值。\n        :type HeadId: int\n        :param Word: 基础词
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Word: str\n        :param Id: 基础词的序号
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Id: int\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Relation: str
+        :param HeadId: 当前词父节点的序号
+注意：此字段可能返回 null，表示取不到有效值。
+        :type HeadId: int
+        :param Word: 基础词
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Word: str
+        :param Id: 基础词的序号
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Id: int
+        """
         self.Relation = None
         self.HeadId = None
         self.Word = None
@@ -754,11 +900,17 @@ class EntityRelationContent(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Object: 实体关系查询返回关系的object
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Object: list of EntityRelationObject\n        :param Relation: 实体关系查询返回的关系名称
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Relation: str\n        :param Subject: 实体关系查询返回关系的subject
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Subject: list of EntityRelationSubject\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Object: list of EntityRelationObject
+        :param Relation: 实体关系查询返回的关系名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Relation: str
+        :param Subject: 实体关系查询返回关系的subject
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Subject: list of EntityRelationSubject
+        """
         self.Object = None
         self.Relation = None
         self.Subject = None
@@ -793,11 +945,17 @@ class EntityRelationObject(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Popular: object对应popular值
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Popular: list of int\n        :param Id: object对应id
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Id: list of str\n        :param Name: object对应name
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Name: list of str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Popular: list of int
+        :param Id: object对应id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Id: list of str
+        :param Name: object对应name
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Name: list of str
+        """
         self.Popular = None
         self.Id = None
         self.Name = None
@@ -822,8 +980,14 @@ class EntityRelationSubject(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Popular: Subject对应popular
+        :type Popular: list of int
+        :param Id: Subject对应id
+        :type Id: list of str
+        :param Name: Subject对应name
+        :type Name: list of str
         """
-        :param Popular: Subject对应popular\n        :type Popular: list of int\n        :param Id: Subject对应id\n        :type Id: list of str\n        :param Name: Subject对应name\n        :type Name: list of str\n        """
         self.Popular = None
         self.Id = None
         self.Name = None
@@ -848,8 +1012,12 @@ class Keyword(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Score: 权重
+        :type Score: float
+        :param Word: 关键词
+        :type Word: str
         """
-        :param Score: 权重\n        :type Score: float\n        :param Word: 关键词\n        :type Word: str\n        """
         self.Score = None
         self.Word = None
 
@@ -872,8 +1040,12 @@ class KeywordsExtractionRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 待处理的文本（仅支持UTF-8格式，不超过10000字符）
+        :type Text: str
+        :param Num: 指定关键词个数上限（默认值为5）
+        :type Num: int
         """
-        :param Text: 待处理的文本（仅支持UTF-8格式，不超过10000字）\n        :type Text: str\n        :param Num: 指定关键词个数上限（默认值为5）\n        :type Num: int\n        """
         self.Text = None
         self.Num = None
 
@@ -896,9 +1068,13 @@ class KeywordsExtractionResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Keywords: 关键词提取结果
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Keywords: list of Keyword\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Keywords: list of Keyword
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.Keywords = None
         self.RequestId = None
 
@@ -919,10 +1095,16 @@ class LexicalAnalysisRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param Text: 待分析的文本（仅支持UTF-8格式，不超过500字）\n        :type Text: str\n        :param DictId: 指定要加载的自定义词库ID。\n        :type DictId: str\n        :param Flag: 词法分析模式（默认取2值）：
+        r"""
+        :param Text: 待分析的文本（仅支持UTF-8格式，不超过500字）
+        :type Text: str
+        :param DictId: 指定要加载的自定义词库ID。
+        :type DictId: str
+        :param Flag: 词法分析模式（默认取2值）：
 1、高精度（混合粒度分词能力）；
-2、高性能（单粒度分词能力）；\n        :type Flag: int\n        """
+2、高性能（单粒度分词能力）；
+        :type Flag: int
+        """
         self.Text = None
         self.DictId = None
         self.Flag = None
@@ -947,13 +1129,19 @@ class LexicalAnalysisResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param NerTokens: 命名实体识别结果。取值范围：
 <li>PER：表示人名，如刘德华、贝克汉姆</li>
 <li>LOC：表示地名，如北京、华山</li>
 <li>ORG：表示机构团体名，如腾讯、最高人民法院、人大附中</li>
 <li>PRODUCTION：表示产品名，如QQ、微信、iPhone</li>
-注意：此字段可能返回 null，表示取不到有效值。\n        :type NerTokens: list of NerToken\n        :param PosTokens: 分词&词性标注结果（词性表请参见附录）\n        :type PosTokens: list of PosToken\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NerTokens: list of NerToken
+        :param PosTokens: 分词&词性标注结果（词性表请参见附录）
+        :type PosTokens: list of PosToken
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.NerTokens = None
         self.PosTokens = None
         self.RequestId = None
@@ -981,8 +1169,16 @@ class NerToken(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Word: 基础词
+        :type Word: str
+        :param Length: 长度
+        :type Length: int
+        :param BeginOffset: 起始位置
+        :type BeginOffset: int
+        :param Type: 命名实体类型
+        :type Type: str
         """
-        :param Word: 基础词\n        :type Word: str\n        :param Length: 长度\n        :type Length: int\n        :param BeginOffset: 起始位置\n        :type BeginOffset: int\n        :param Type: 命名实体类型\n        :type Type: str\n        """
         self.Word = None
         self.Length = None
         self.BeginOffset = None
@@ -1009,8 +1205,16 @@ class PosToken(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Word: 基础词
+        :type Word: str
+        :param Length: 长度
+        :type Length: int
+        :param BeginOffset: 起始位置
+        :type BeginOffset: int
+        :param Pos: 词性
+        :type Pos: str
         """
-        :param Word: 基础词\n        :type Word: str\n        :param Length: 长度\n        :type Length: int\n        :param BeginOffset: 起始位置\n        :type BeginOffset: int\n        :param Pos: 词性\n        :type Pos: str\n        """
         self.Word = None
         self.Length = None
         self.BeginOffset = None
@@ -1037,10 +1241,18 @@ class SearchResult(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 被搜索的词条文本。
+        :type Text: str
+        :param IsExist: 0表示词条不存在，1表示存在。
+        :type IsExist: int
+        :param MatchText: 匹配到的词条文本。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type MatchText: str
+        :param Pos: 词条的词性。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Pos: str
         """
-        :param Text: 被搜索的词条文本。\n        :type Text: str\n        :param IsExist: 0表示词条不存在，1表示存在。\n        :type IsExist: int\n        :param MatchText: 匹配到的词条文本。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type MatchText: str\n        :param Pos: 词条的词性。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Pos: str\n        """
         self.Text = None
         self.IsExist = None
         self.MatchText = None
@@ -1067,8 +1279,12 @@ class SearchWordItemsRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param DictId: 自定义词库ID。
+        :type DictId: str
+        :param WordItems: 待检索的词条集合。
+        :type WordItems: list of WordItem
         """
-        :param DictId: 自定义词库ID。\n        :type DictId: str\n        :param WordItems: 待检索的词条集合。\n        :type WordItems: list of WordItem\n        """
         self.DictId = None
         self.WordItems = None
 
@@ -1096,9 +1312,13 @@ class SearchWordItemsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Results: 词条检索结果集合。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Results: list of SearchResult\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Results: list of SearchResult
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.Results = None
         self.RequestId = None
 
@@ -1119,8 +1339,10 @@ class SentenceEmbeddingRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 输入的文本（仅支持UTF-8格式，不超过500字）
+        :type Text: str
         """
-        :param Text: 输入的文本（仅支持UTF-8格式，不超过500字）\n        :type Text: str\n        """
         self.Text = None
 
 
@@ -1141,8 +1363,14 @@ class SentenceEmbeddingResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Vector: 句向量数组
+        :type Vector: list of float
+        :param Dimension: 句向量的维度
+        :type Dimension: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Vector: 句向量数组\n        :type Vector: list of float\n        :param Dimension: 句向量的维度\n        :type Dimension: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Vector = None
         self.Dimension = None
         self.RequestId = None
@@ -1160,14 +1388,20 @@ class SentimentAnalysisRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param Text: 待分析的文本（仅支持UTF-8格式，不超过200字）\n        :type Text: str\n        :param Flag: 待分析文本所属的类型，仅当输入参数Mode取值为2class时有效（默认取4值）：
+        r"""
+        :param Text: 待分析的文本（仅支持UTF-8格式，不超过200字）
+        :type Text: str
+        :param Flag: 待分析文本所属的类型，仅当输入参数Mode取值为2class时有效（默认取4值）：
 1、商品评论类
 2、社交类
 3、美食酒店类
-4、通用领域类\n        :type Flag: int\n        :param Mode: 情感分类模式选项，可取2class或3class（默认值为2class）
+4、通用领域类
+        :type Flag: int
+        :param Mode: 情感分类模式选项，可取2class或3class（默认值为2class）
 1、2class：返回正负面二分类情感结果
-2、3class：返回正负面及中性三分类情感结果\n        :type Mode: str\n        """
+2、3class：返回正负面及中性三分类情感结果
+        :type Mode: str
+        """
         self.Text = None
         self.Flag = None
         self.Mode = None
@@ -1192,12 +1426,22 @@ class SentimentAnalysisResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param Positive: 正面情感概率\n        :type Positive: float\n        :param Neutral: 中性情感概率，当输入参数Mode取值为3class时有效，否则值为空
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Neutral: float\n        :param Negative: 负面情感概率\n        :type Negative: float\n        :param Sentiment: 情感分类结果：
+        r"""
+        :param Positive: 正面情感概率
+        :type Positive: float
+        :param Neutral: 中性情感概率，当输入参数Mode取值为3class时有效，否则值为空
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Neutral: float
+        :param Negative: 负面情感概率
+        :type Negative: float
+        :param Sentiment: 情感分类结果：
 1、positive，表示正面情感
 2、negative，表示负面情感
-3、neutral，表示中性、无情感\n        :type Sentiment: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+3、neutral，表示中性、无情感
+        :type Sentiment: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.Positive = None
         self.Neutral = None
         self.Negative = None
@@ -1219,8 +1463,12 @@ class SimilarWordsRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 输入的词语（仅支持UTF-8格式，不超过20字）
+        :type Text: str
+        :param WordNumber: 相似词个数；取值范围：1-200，默认为10；
+        :type WordNumber: int
         """
-        :param Text: 输入的词语（仅支持UTF-8格式，不超过20字）\n        :type Text: str\n        :param WordNumber: 相似词个数；取值范围：1-200，默认为10；\n        :type WordNumber: int\n        """
         self.Text = None
         self.WordNumber = None
 
@@ -1243,8 +1491,12 @@ class SimilarWordsResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param SimilarWords: 相似词数组
+        :type SimilarWords: list of str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param SimilarWords: 相似词数组\n        :type SimilarWords: list of str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SimilarWords = None
         self.RequestId = None
 
@@ -1260,8 +1512,12 @@ class Similarity(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 目标文本句子
+        :type Text: str
+        :param Score: 相似度分数
+        :type Score: float
         """
-        :param Text: 目标文本句子\n        :type Text: str\n        :param Score: 相似度分数\n        :type Score: float\n        """
         self.Text = None
         self.Score = None
 
@@ -1284,10 +1540,14 @@ class TextClassificationRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param Text: 待分类的文本（仅支持UTF-8格式，不超过10000字）\n        :type Text: str\n        :param Flag: 领域分类体系（默认取1值）：
+        r"""
+        :param Text: 待分类的文本（仅支持UTF-8格式，不超过10000字）
+        :type Text: str
+        :param Flag: 领域分类体系（默认取1值）：
 1、通用领域，二分类
-2、新闻领域，五分类。类别数据不一定全部返回，详情见类目映射表\n        :type Flag: int\n        """
+2、新闻领域，五分类。类别数据不一定全部返回，详情见类目映射表
+        :type Flag: int
+        """
         self.Text = None
         self.Flag = None
 
@@ -1310,8 +1570,12 @@ class TextClassificationResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Classes: 文本分类结果（文本分类映射表请参见附录）
+        :type Classes: list of ClassificationResult
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Classes: 文本分类结果（文本分类映射表请参见附录）\n        :type Classes: list of ClassificationResult\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Classes = None
         self.RequestId = None
 
@@ -1332,8 +1596,10 @@ class TextCorrectionRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 待纠错的文本（仅支持UTF-8格式，不超过2000字符）
+        :type Text: str
         """
-        :param Text: 待纠错的文本（仅支持UTF-8格式，不超过2000字符）\n        :type Text: str\n        """
         self.Text = None
 
 
@@ -1354,9 +1620,15 @@ class TextCorrectionResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param CCITokens: 纠错详情
-注意：此字段可能返回 null，表示取不到有效值。\n        :type CCITokens: list of CCIToken\n        :param ResultText: 纠错后的文本\n        :type ResultText: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CCITokens: list of CCIToken
+        :param ResultText: 纠错后的文本
+        :type ResultText: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
         self.CCITokens = None
         self.ResultText = None
         self.RequestId = None
@@ -1379,8 +1651,12 @@ class TextSimilarityRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param SrcText: 需要与目标句子计算相似度的源句子（仅支持UTF-8格式，不超过500字符）
+        :type SrcText: str
+        :param TargetText: 目标句子（以句子数量为单位消耗资源包）
+        :type TargetText: list of str
         """
-        :param SrcText: 需要与目标句子计算相似度的源句子（仅支持UTF-8格式，不超过500字符）\n        :type SrcText: str\n        :param TargetText: 目标句子\n        :type TargetText: list of str\n        """
         self.SrcText = None
         self.TargetText = None
 
@@ -1403,8 +1679,12 @@ class TextSimilarityResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Similarity: 每个目标句子与源句子的相似度分值，按照分值降序排列
+        :type Similarity: list of Similarity
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Similarity: 每个目标句子与源句子的相似度分值，按照分值降序排列\n        :type Similarity: list of Similarity\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Similarity = None
         self.RequestId = None
 
@@ -1425,12 +1705,20 @@ class TripleContent(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Popular: 实体流行度
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Popular: int\n        :param Name: 实体名称
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Name: str\n        :param Order: 实体order
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Order: int\n        :param Id: 实体id
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Id: str\n        """
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Popular: int
+        :param Name: 实体名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Name: str
+        :param Order: 实体order
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Order: int
+        :param Id: 实体id
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Id: str
+        """
         self.Popular = None
         self.Name = None
         self.Order = None
@@ -1457,8 +1745,14 @@ class UpdateDictRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param DictId: 自定义词库ID。
+        :type DictId: str
+        :param Description: 词库描述，不超过100字。
+        :type Description: str
+        :param Name: 词库名称，不超过20字。
+        :type Name: str
         """
-        :param DictId: 自定义词库ID。\n        :type DictId: str\n        :param Description: 词库描述，不超过100字。\n        :type Description: str\n        :param Name: 词库名称，不超过20字。\n        :type Name: str\n        """
         self.DictId = None
         self.Description = None
         self.Name = None
@@ -1483,8 +1777,10 @@ class UpdateDictResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -1498,8 +1794,10 @@ class WordEmbeddingRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 输入的词语（仅支持UTF-8格式，不超过20字）
+        :type Text: str
         """
-        :param Text: 输入的词语（仅支持UTF-8格式，不超过20字）\n        :type Text: str\n        """
         self.Text = None
 
 
@@ -1520,8 +1818,14 @@ class WordEmbeddingResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Vector: 词向量数组
+        :type Vector: list of float
+        :param Dimension: 词向量的维度
+        :type Dimension: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Vector: 词向量数组\n        :type Vector: list of float\n        :param Dimension: 词向量的维度\n        :type Dimension: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Vector = None
         self.Dimension = None
         self.RequestId = None
@@ -1539,9 +1843,15 @@ class WordItem(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Text: 词条文本内容。
+        :type Text: str
+        :param CreateTime: 词条创建时间。
+        :type CreateTime: str
+        :param Pos: 词条的词性。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Pos: str
         """
-        :param Text: 词条文本内容。\n        :type Text: str\n        :param CreateTime: 词条创建时间。\n        :type CreateTime: str\n        :param Pos: 词条的词性。
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Pos: str\n        """
         self.Text = None
         self.CreateTime = None
         self.Pos = None
@@ -1566,8 +1876,12 @@ class WordSimilarityRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param SrcWord: 计算相似度的源词（仅支持UTF-8格式，不超过20字）
+        :type SrcWord: str
+        :param TargetWord: 计算相似度的目标词（仅支持UTF-8格式，不超过20字）
+        :type TargetWord: str
         """
-        :param SrcWord: 计算相似度的源词（仅支持UTF-8格式，不超过20字）\n        :type SrcWord: str\n        :param TargetWord: 计算相似度的目标词（仅支持UTF-8格式，不超过20字）\n        :type TargetWord: str\n        """
         self.SrcWord = None
         self.TargetWord = None
 
@@ -1590,8 +1904,12 @@ class WordSimilarityResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Similarity: 两个词语的相似度
+        :type Similarity: float
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Similarity: 两个词语的相似度\n        :type Similarity: float\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Similarity = None
         self.RequestId = None
 
